'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = loadCore;

var _getNextCoreId = require('./getNextCoreId');

var _getNextCoreId2 = _interopRequireDefault(_getNextCoreId);

var _operations = require('./operations');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function coreInfo(context) {
  return {
    id: context._core.id,
    args: context._core.args,
    destroyCore: function destroyCore() {
      return (0, _operations.destroyCore)(context);
    },
    context: context
  };
}

function loadCore(opts) {
  var uidocument = arguments.length <= 1 || arguments[1] === undefined ? window._core.uidocument : arguments[1];

  return new Promise(function (resolve, reject) {
    var coreId = (0, _getNextCoreId2.default)(uidocument);
    var envEl = uidocument.createElement('iframe');
    envEl.setAttribute('data-coreid', coreId);
    uidocument.body.appendChild(envEl);

    var envDoc = envEl.contentDocument;
    envDoc.open();

    var envContext = envEl.contentWindow;
    var coreData = envContext._core = {
      id: coreId,
      uidocument: uidocument,
      args: opts.args,

      onReady: function onReady(handlers) {
        coreData.attach = handlers.attach;
        coreData.detach = handlers.detach;
        resolve(_extends({
          launchCore: function launchCore() {
            return (0, _operations.swapCore)(window, envContext, uidocument);
          }
        }, coreInfo(envContext)));
      },
      onExecutionError: function onExecutionError(err) {
        reject(_extends({
          type: 'js',
          err: err
        }, coreInfo(envContext)));
      },
      onLoadError: function onLoadError(src) {
        reject(_extends({
          type: 'request',
          src: src
        }, coreInfo(envContext)));
      }
    };

    var contentHTML = '<!doctype html><html><body><script src="' + opts.scriptURL + '" onerror="_core.onLoadError(this.src)"></script></body></html>';
    envDoc.write(contentHTML);
    envDoc.close();
  });
}